const dbName = "myDatabase";
const storeName = "images";

export const openDatabase = async (): Promise<IDBDatabase> => {
  return new Promise((resolve, reject) => {
    const request = indexedDB.open(dbName);

    request.onupgradeneeded = (event: IDBVersionChangeEvent) => {
      const db = request.result;
      if (!db.objectStoreNames.contains(storeName)) {
        db.createObjectStore(storeName);
      }
    };

    request.onerror = (event) => reject(request.error);
    request.onsuccess = (event) => resolve(request.result);
  });
};

export const saveImageToIndexedDB = async (outputImage: any) => {
  try {
    const db = await openDatabase();

    const transaction = db.transaction(storeName, "readwrite");
    const store = transaction.objectStore(storeName);

    const request = store.put(outputImage, "outputImageKey");
    request.onerror = (event) =>
      console.error("Error saving to IndexedDB", request.error);
    request.onsuccess = (event) => console.log("Image saved to IndexedDB");
  } catch (error) {
    console.error("Error with IndexedDB operation", error);
  }
};

export const loadImageFromIndexedDB = async (): Promise<any> => {
  try {
    const db = await openDatabase();

    const transaction = db.transaction(storeName, "readonly");
    const store = transaction.objectStore(storeName);

    const request = store.get("outputImageKey");
    return new Promise((resolve, reject) => {
      request.onerror = (event) => {
        console.error("Error fetching from IndexedDB", request.error);
        reject(request.error);
      };
      request.onsuccess = (event) => {
        if (request.result) {
          console.log("Image loaded from IndexedDB");
          resolve(request.result);
        } else {
          console.log("No data found in IndexedDB");
          resolve(null);
        }
      };
    });
  } catch (error) {
    console.error("Error with IndexedDB operation", error);
    throw error;
  }
};

export const checkExistenceInIndexedDB = async (
  key: string
): Promise<boolean> => {
  try {
    const dbName = "myDatabase";
    const storeName = "images";
    const db = await openDatabase();

    const transaction = db.transaction(storeName, "readonly");
    const store = transaction.objectStore(storeName);

    const request = store.get(key);

    return new Promise((resolve, reject) => {
      request.onerror = (event) => {
        console.error("Error fetching from IndexedDB", request.error);
        reject(request.error);
      };
      request.onsuccess = (event) => {
        resolve(request.result !== undefined);
      };
    });
  } catch (error) {
    console.error("Error with IndexedDB operation", error);
    throw error;
  }
};
